import path from 'path';
import { getCwdPath } from './cwd.js';
jest.mock('../utils/fs', () => {
    const actual = jest.requireActual('../utils/fs');
    let mocked = false;
    let fileMocks = {};
    let dirMocks = [];
    async function importModule(moduleId) {
        if (!mocked)
            return actual.importModule(moduleId);
        return fileMocks[moduleId] || fileMocks[`${moduleId}.js`];
    }
    function moduleExists(moduleId) {
        if (!mocked)
            return actual.moduleExists(moduleId);
        return (fileMocks.hasOwnProperty(moduleId) ||
            fileMocks.hasOwnProperty(`${moduleId}.js`));
    }
    function fileExists(filePath) {
        if (!mocked)
            return actual.fileExists(filePath);
        return fileMocks.hasOwnProperty(filePath);
    }
    function dirExists(dirPath) {
        if (!mocked)
            return actual.dirExists(dirPath);
        return dirMocks.indexOf(dirPath) !== -1;
    }
    return {
        importModule,
        moduleExists,
        fileExists,
        dirExists,
        __mockFile(filePath, fileMock) {
            mocked = true;
            fileMocks = { ...fileMocks, [filePath]: fileMock };
        },
        __mockDir(dirPath) {
            mocked = true;
            dirMocks = [...dirMocks, dirPath];
        },
        __resetMock() {
            fileMocks = {};
            dirMocks = [];
        },
    };
});
export function mockCosmosConfig(cosmosConfigPath, cosmosConfig) {
    mockFile(cosmosConfigPath, cosmosConfig);
}
export function mockFile(filePath, fileContent) {
    const absPath = getCwdPath(filePath);
    requireMocked().__mockFile(absPath, fileContent);
    requireMocked().__mockDir(path.dirname(absPath));
}
export function mockDir(dirPath) {
    requireMocked().__mockDir(getCwdPath(dirPath));
}
export function resetFsMock() {
    requireMocked().__resetMock();
}
function requireMocked() {
    return require('../utils/fs.js');
}
